summaryrefslogtreecommitdiff
path: root/gdb/amd64obsd-tdep.c
diff options
context:
space:
mode:
authorDaniel Jacobowitz <dan@debian.org>2008-04-30 21:19:45 +0000
committerDaniel Jacobowitz <dan@debian.org>2008-04-30 21:19:45 +0000
commit2d9d5c061f931d460488533d67726ba9a939153f (patch)
treea2a85aa0a09eecf06c64d288cc1180a9bf0f274f /gdb/amd64obsd-tdep.c
parente4af005e4ad58885f85664d46658b5ac591f86f6 (diff)
downloadgdb-2d9d5c061f931d460488533d67726ba9a939153f.tar.gz
Update i386 and amd64 ports for unwinder changes.
* amd64-tdep.c (amd64_frame_cache): Expect this_frame. (amd64_frame_this_id, amd64_frame_prev_register): Update signature. (amd64_frame_unwind): Use default_frame_sniffer. (amd64_frame_sniffer): Delete. (amd64_sigtramp_frame_cache): Expect this_frame. (amd64_sigtramp_frame_this_id, amd64_sigtramp_frame_prev_register) (amd64_sigtramp_frame_sniffer): Update signature. (amd64_sigtramp_frame_unwind): Add amd64_sigtramp_frame_sniffer. (amd64_frame_base_address): Expect this_frame. (amd64_dummy_id): Renamed from amd64_unwind_dummy_id. Expect this_frame. (amd64_init_abi): Use set_gdbarch_dummy_id and frame_unwind_append_unwinder. * i386-tdep.c (i386_frame_cache): Expect this_frame. (i386_frame_this_id, i386_frame_prev_register): Update signature. (i386_frame_unwind): Use default_frame_sniffer. (i386_frame_sniffer): Delete. (i386_sigtramp_frame_cache): Expect this_frame. (i386_sigtramp_frame_this_id, i386_sigtramp_frame_prev_register) (i386_sigtramp_frame_sniffer): Update signature. (i386_sigtramp_frame_unwind): Use i386_sigtramp_frame_sniffer. (i386_frame_base_address): Update signature. (i386_dummy_id): Rename from i386_unwind_dummy_id. Expect this_frame. (i386_push_dummy_call): Update comment. (i386_sigtramp_p, i386_svr4_sigtramp_p, i386_svr4_sigcontext_addr): Expect this_frame. (i386_gdbarch_init): Use set_gdbarch_dummy_id, dwarf2_append_unwinders, and frame_unwind_append_unwinder. * amd64-linux-tdep.c, amd64-sol2-tdep.c, amd64fbsd-tdep.c, amd64nbsd-tdep.c, amd64obsd-tdep.c, i386-linux-tdep.c, i386-nto-tdep.c, i386bsd-tdep.c, i386-sol2-tdep.c, i386obsd-tdep.c, i386nbsd-tdep.c: Update for unwinder changes.
Diffstat (limited to 'gdb/amd64obsd-tdep.c')
-rw-r--r--gdb/amd64obsd-tdep.c56
1 files changed, 25 insertions, 31 deletions
diff --git a/gdb/amd64obsd-tdep.c b/gdb/amd64obsd-tdep.c
index 2460e009d93..1a0cfac22a3 100644
--- a/gdb/amd64obsd-tdep.c
+++ b/gdb/amd64obsd-tdep.c
@@ -79,13 +79,13 @@ amd64obsd_regset_from_core_section (struct gdbarch *gdbarch,
/* Default page size. */
static const int amd64obsd_page_size = 4096;
-/* Return whether the frame preceding NEXT_FRAME corresponds to an
- OpenBSD sigtramp routine. */
+/* Return whether THIS_FRAME corresponds to an OpenBSD sigtramp
+ routine. */
static int
-amd64obsd_sigtramp_p (struct frame_info *next_frame)
+amd64obsd_sigtramp_p (struct frame_info *this_frame)
{
- CORE_ADDR pc = frame_pc_unwind (next_frame);
+ CORE_ADDR pc = get_frame_pc (this_frame);
CORE_ADDR start_pc = (pc & ~(amd64obsd_page_size - 1));
const gdb_byte sigreturn[] =
{
@@ -110,7 +110,7 @@ amd64obsd_sigtramp_p (struct frame_info *next_frame)
/* If we can't read the instructions at START_PC, return zero. */
buf = alloca ((sizeof sigreturn) + 1);
- if (!safe_frame_unwind_memory (next_frame, start_pc + 6, buf, buflen))
+ if (!safe_frame_unwind_memory (this_frame, start_pc + 6, buf, buflen))
return 0;
/* Check for sigreturn(2). Depending on how the assembler encoded
@@ -123,13 +123,13 @@ amd64obsd_sigtramp_p (struct frame_info *next_frame)
return 1;
}
-/* Assuming NEXT_FRAME is for a frame following a BSD sigtramp
- routine, return the address of the associated sigcontext structure. */
+/* Assuming THIS_FRAME is for a BSD sigtramp routine, return the
+ address of the associated sigcontext structure. */
static CORE_ADDR
-amd64obsd_sigcontext_addr (struct frame_info *next_frame)
+amd64obsd_sigcontext_addr (struct frame_info *this_frame)
{
- CORE_ADDR pc = frame_pc_unwind (next_frame);
+ CORE_ADDR pc = get_frame_pc (this_frame);
ULONGEST offset = (pc & (amd64obsd_page_size - 1));
/* The %rsp register points at `struct sigcontext' upon entry of a
@@ -145,9 +145,9 @@ amd64obsd_sigcontext_addr (struct frame_info *next_frame)
instruction clobbers %rsp, but its value is saved in `%rdi'. */
if (offset > 5)
- return frame_unwind_register_unsigned (next_frame, AMD64_RDI_REGNUM);
+ return get_frame_register_unsigned (this_frame, AMD64_RDI_REGNUM);
else
- return frame_unwind_register_unsigned (next_frame, AMD64_RSP_REGNUM);
+ return get_frame_register_unsigned (this_frame, AMD64_RSP_REGNUM);
}
/* OpenBSD 3.5 or later. */
@@ -340,7 +340,7 @@ amd64obsd_collect_uthread (const struct regcache *regcache,
#define amd64obsd_tf_reg_offset amd64obsd_sc_reg_offset
static struct trad_frame_cache *
-amd64obsd_trapframe_cache(struct frame_info *next_frame, void **this_cache)
+amd64obsd_trapframe_cache (struct frame_info *this_frame, void **this_cache)
{
struct trad_frame_cache *cache;
CORE_ADDR func, sp, addr;
@@ -351,13 +351,11 @@ amd64obsd_trapframe_cache(struct frame_info *next_frame, void **this_cache)
if (*this_cache)
return *this_cache;
- cache = trad_frame_cache_zalloc (next_frame);
+ cache = trad_frame_cache_zalloc (this_frame);
*this_cache = cache;
- /* NORMAL_FRAME matches the type in amd64obsd_trapframe_unwind, but
- SIGTRAMP_FRAME might be more appropriate. */
- func = frame_func_unwind (next_frame, NORMAL_FRAME);
- sp = frame_unwind_register_unsigned (next_frame, AMD64_RSP_REGNUM);
+ func = get_frame_func (this_frame);
+ sp = get_frame_register_unsigned (this_frame, AMD64_RSP_REGNUM);
find_pc_partial_function (func, &name, NULL, NULL);
if (name && strncmp (name, "Xintr", 5) == 0)
@@ -387,32 +385,28 @@ amd64obsd_trapframe_cache(struct frame_info *next_frame, void **this_cache)
}
static void
-amd64obsd_trapframe_this_id (struct frame_info *next_frame,
+amd64obsd_trapframe_this_id (struct frame_info *this_frame,
void **this_cache, struct frame_id *this_id)
{
struct trad_frame_cache *cache =
- amd64obsd_trapframe_cache (next_frame, this_cache);
+ amd64obsd_trapframe_cache (this_frame, this_cache);
trad_frame_get_id (cache, this_id);
}
-static void
-amd64obsd_trapframe_prev_register (struct frame_info *next_frame,
- void **this_cache, int regnum,
- int *optimizedp, enum lval_type *lvalp,
- CORE_ADDR *addrp, int *realnump,
- gdb_byte *valuep)
+static struct value *
+amd64obsd_trapframe_prev_register (struct frame_info *this_frame,
+ void **this_cache, int regnum)
{
struct trad_frame_cache *cache =
- amd64obsd_trapframe_cache (next_frame, this_cache);
+ amd64obsd_trapframe_cache (this_frame, this_cache);
- trad_frame_get_register (cache, next_frame, regnum,
- optimizedp, lvalp, addrp, realnump, valuep);
+ return trad_frame_get_register (cache, this_frame, regnum);
}
static int
amd64obsd_trapframe_sniffer (const struct frame_unwind *self,
- struct frame_info *next_frame,
+ struct frame_info *this_frame,
void **this_prologue_cache)
{
ULONGEST cs;
@@ -420,11 +414,11 @@ amd64obsd_trapframe_sniffer (const struct frame_unwind *self,
/* Check Current Privilege Level and bail out if we're not executing
in kernel space. */
- cs = frame_unwind_register_unsigned (next_frame, AMD64_CS_REGNUM);
+ cs = get_frame_register_unsigned (this_frame, AMD64_CS_REGNUM);
if ((cs & I386_SEL_RPL) == I386_SEL_UPL)
return 0;
- find_pc_partial_function (frame_pc_unwind (next_frame), &name, NULL, NULL);
+ find_pc_partial_function (get_frame_pc (this_frame), &name, NULL, NULL);
return (name && ((strcmp (name, "calltrap") == 0)
|| (strcmp (name, "osyscall1") == 0)
|| (strcmp (name, "Xsyscall") == 0)